module.exports = function(grunt) {

	require("load-grunt-tasks")(grunt);

	grunt.initConfig({

		pkg: grunt.file.readJSON("package.json"),

		clean: [
			"dist/jquery.slidebox.css",
			"dist/jquery.slidebox.min.css",
			"dist/jquery.slidebox.js",
			"dist/jquery.slidebox.min.js"
		],

		meta: {
			banner: "/*\n" +
				" *  <%= pkg.title || pkg.name %> - v<%= pkg.version %>\n" +
				" *  <%= pkg.description %>\n" +
				" *  <%= pkg.homepage %>\n" +
				" *\n" +
				" *  Copyright <%= pkg.author.name %>, <<%= pkg.author.email %>>\n" +
				" *  Under <%= pkg.license %> License\n" +
				" */\n"
		},

		concat: {
			options: {
				banner: "<%= meta.banner %>"
			},
			dist: {
				src: ["src/jquery.slidebox.js"],
				dest: "dist/jquery.slidebox.js"
			}
		},

		jshint: {
			files: ["src/jquery.slidebox.js"],
			options: {
				jshintrc: ".jshintrc"
			}
		},

		uglify: {
			dist: {
				src: ["dist/jquery.slidebox.js"],
				dest: "dist/jquery.slidebox.min.js"
			},
			options: {
				banner: "<%= meta.banner %>"
			}
		},

		sass: {
			options: {
				loadPath: "bower_components",
				sourcemap: "none"
			},
			dist: {
				files: {
					"dist/jquery.slidebox.css": "src/jquery.slidebox.scss"
				}
			}
		},

		cssmin: {
		   dist: {
		     files: {
				 "dist/jquery.slidebox.min.css": "dist/jquery.slidebox.css"
			 }
		   }
		},

		watch: {
		    files: ["src/*"],
		    tasks: ["default"]
		}

	});

	grunt.registerTask("build", ["clean", "concat", "uglify", 'sass', 'cssmin']);
	grunt.registerTask("default", ["jshint", "build"]);

};
